@@ -8,7 +8,6 @@ import contextlib
 import os
 import sys
 import time
-
 from io import StringIO
 from unittest.mock import patch
 
@@ -20,6 +19,11 @@ from scxpand.main import fire, inference, list_pretrained_models, main, optimize
 from scxpand.util.classes import ModelType
 
 
+@pytest.fixture(autouse=True, scope="module")
+def ensure_data_dir():
+    os.makedirs("data", exist_ok=True)
+
+
 class TestCLIUnit:
     """Fast unit tests with proper mocking - no subprocess calls."""
 
@@ -60,7 +64,9 @@ class TestCLIUnit:
         assert hasattr(fire, "Fire")
         assert callable(fire.Fire)
 
-    @pytest.mark.parametrize("command", ["train", "optimize", "optimize-all", "inference", "list-models"])
+    @pytest.mark.parametrize(
+        "command", ["train", "optimize", "optimize-all", "inference", "list-models"]
+    )
     def test_cli_command_availability(self, command):
         """Test that each CLI command is available through Fire."""
         with patch("scxpand.main.fire.Fire") as mock_fire:
@@ -151,7 +157,9 @@ class TestCLIFunctionIntegration:
     @patch("scxpand.main.get_new_version_path")
     @patch("scxpand.main.load_and_override_params")
     @patch("scxpand.main.call_training_function")
-    def test_train_function_integration(self, mock_call_training, mock_load_params, mock_get_path, mock_validate):
+    def test_train_function_integration(
+        self, mock_call_training, mock_load_params, mock_get_path, mock_validate
+    ):
         """Test train function integration with CLI."""
         # Mock all dependencies
 
@@ -204,7 +212,9 @@ class TestCLIFunctionIntegration:
 
     @patch("scxpand.main.run_inference")
     @patch("scxpand.main.load_eval_indices")
-    def test_inference_function_integration(self, mock_load_indices, mock_run_inference):
+    def test_inference_function_integration(
+        self, mock_load_indices, mock_run_inference
+    ):
         """Test inference function integration with CLI."""
         # Mock dependencies
         mock_load_indices.return_value = None
@@ -343,7 +353,9 @@ class TestCLIPerformance:
 
             # CLI should start up in less than 1 second
             startup_time = end_time - start_time
-            assert startup_time < 1.0, f"CLI startup took {startup_time:.3f}s, should be < 1.0s"
+            assert startup_time < 1.0, (
+                f"CLI startup took {startup_time:.3f}s, should be < 1.0s"
+            )
 
     def test_cli_memory_usage(self):
         """Test that CLI doesn't use excessive memory."""
